# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dig_ass_chat_protos/DigitalAssistantChatManager.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dig_ass_chat_protos/DigitalAssistantChatManager.proto\x12\x12\x64ig.ass.manager.v1\"3\n#DigitalAssistantChatManagerResponse\x12\x0c\n\x04Text\x18\x01 \x01(\t\"n\n\"DigitalAssistantChatManagerRequest\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12:\n\x0cOuterContext\x18\x02 \x01(\x0b\x32$.dig.ass.manager.v1.OuterContextItem\"r\n\x10OuterContextItem\x12\x0b\n\x03Sex\x18\x01 \x01(\x08\x12\x0b\n\x03\x41ge\x18\x02 \x01(\r\x12\x0e\n\x06UserId\x18\x03 \x01(\t\x12\x11\n\tSessionId\x18\x04 \x01(\t\x12\x10\n\x08\x43lientId\x18\x05 \x01(\t\x12\x0f\n\x07TrackId\x18\x06 \x01(\t2\xa2\x01\n\x1b\x44igitalAssistantChatManager\x12\x82\x01\n\x0fGetTextResponse\x12\x36.dig.ass.manager.v1.DigitalAssistantChatManagerRequest\x1a\x37.dig.ass.manager.v1.DigitalAssistantChatManagerResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dig_ass_chat_protos.DigitalAssistantChatManager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIGITALASSISTANTCHATMANAGERRESPONSE']._serialized_start=77
  _globals['_DIGITALASSISTANTCHATMANAGERRESPONSE']._serialized_end=128
  _globals['_DIGITALASSISTANTCHATMANAGERREQUEST']._serialized_start=130
  _globals['_DIGITALASSISTANTCHATMANAGERREQUEST']._serialized_end=240
  _globals['_OUTERCONTEXTITEM']._serialized_start=242
  _globals['_OUTERCONTEXTITEM']._serialized_end=356
  _globals['_DIGITALASSISTANTCHATMANAGER']._serialized_start=359
  _globals['_DIGITALASSISTANTCHATMANAGER']._serialized_end=521
# @@protoc_insertion_point(module_scope)
